# Copyright 1999-2004 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

inherit linux-mod linux-info eutils

MY_P="OZSCR_2.0.3_Kern_2.6"
S=${WORKDIR}/${MY_P}

DESCRIPTION="O2Micro SmartCardBus PCMCIA Smartcard Reader"
HOMEPAGE="http://www.musclecard.com/sourcedrivers.html"
SRC_URI="ftp://scrdriver:scrdriver@209.19.104.194/Linux/O2Micro_PCMCIA_SCR_203_Linux_Kernel26_OpenSource.tar.gz"

IUSE="debug"

LICENSE="LGPL"
KEYWORDS="x86"

DEPEND=">=sys-devel/gcc-2.95.3-r5
	>=sys-apps/pcsc-lite-1.3.0
	sys-apps/pcmcia-cs"

BUILD_PARAMS="KSRC=${ROOT}${KV_DIR} KVERS=${KV_MAJOR}${KV_MINOR}"

pkg_setup(){
	# setup module dir according to kernel version
	linux-info_pkg_setup
	if [ ${KV_PATCH} -lt 13 ]; then
		einfo "Using kernel module for kernel version less than 2.6.13"
		MODDIR="${S}/src/ozscrlx-2.6"
	else
		einfo "Using kernel module for kernel version 2.6.13 upwards"
		MODDIR="${S}/src/ozscrlx-2.6.13"
	fi
	
	if use debug; then
		BUILD_PARAMS="$BUILD_PARAMS debug=1"
		BUILD_TARGETS="clean default"
	else
		BUILD_TARGETS="clean default"
	fi
	MODULE_NAMES="ozscrlx(pcmcia:${MODDIR}:${MODDIR})"
	
	linux-mod_pkg_setup
}

src_unpack() {
	unpack ${A}
	cd ${S}
	# Fix lib paths for gentoo
	sed -i -e 's#/usr/local/o2micro/lib_OZSCR.so#/usr/lib/readers/lib_OZSCR.so#' etc/reader.conf.1.2.9
	sed -i -e 's#/usr/local/include/PCSC#/usr/include/PCSC#' src/ozctapi/Makefile
	sed -i -e 's#-DCPU_ICAP_PC#-DCPU_ICAP_PC -fPIC#' src/ozctapi/Makefile
	if [ ${KV_PATCH} -eq 16 ]; then
		einfo "Patching ozscrlx.c for kernel version 2.6.16"
		epatch ${FILESDIR}/ozscrlx-203-kernel-2.6.16.patch
	fi
	if [ ${KV_PATCH} -gt 16 ]; then
		einfo "Patching ozscrlx.c for kernel version 2.6.17 (and above?)"
		epatch ${FILESDIR}/ozscrlx-203-kernel-2.6.17-config.patch
		epatch ${FILESDIR}/ozscrlx-203-kernel-2.6.17-sysfs.patch
	fi
}


src_compile() {
	if use debug; then
		MAKEOPTS="debug=1"
	fi
	emake -C src/ozctapi || die
	linux-mod_src_compile
}

src_install() {
	dodoc INSTALL doc/*

	exeinto /usr/lib/readers
	doexe src/ozctapi/lib_OZSCR.so

	insinto /etc/reader.conf.d
	newins etc/reader.conf.1.2.9 o2micro_ozscr.conf

	insinto /etc/pcmcia
	doins etc/pcmcia/O2MICRO.conf
	doins etc/pcmcia/smartcardreader-ozscr

	insinto /etc/udev/rules.d
	doins ${FILESDIR}/60-o2cr.rules

	linux-mod_src_install
}

pkg_postinst() {
	linux-mod_pkg_postinst

	einfo "Regenerating /etc/reader.conf..."
	update-reader.conf
}
